summaryrefslogtreecommitdiffstats
path: root/chromium/ui/views/corewm/tooltip_controller.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/ui/views/corewm/tooltip_controller.h')
-rw-r--r--chromium/ui/views/corewm/tooltip_controller.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/chromium/ui/views/corewm/tooltip_controller.h b/chromium/ui/views/corewm/tooltip_controller.h
index 66b6a3224c7..e0453341f00 100644
--- a/chromium/ui/views/corewm/tooltip_controller.h
+++ b/chromium/ui/views/corewm/tooltip_controller.h
@@ -10,11 +10,11 @@
#include "base/memory/scoped_ptr.h"
#include "base/strings/string16.h"
#include "base/timer/timer.h"
-#include "ui/aura/client/tooltip_client.h"
#include "ui/aura/window_observer.h"
#include "ui/events/event_handler.h"
#include "ui/gfx/point.h"
#include "ui/views/views_export.h"
+#include "ui/wm/public/tooltip_client.h"
namespace aura {
class Window;
@@ -61,7 +61,7 @@ class VIEWS_EXPORT TooltipController : public aura::client::TooltipClient,
void TooltipShownTimerFired();
// Updates the tooltip if required (if there is any change in the tooltip
// text or the aura::Window.
void UpdateIfRequired();
// Only used in tests.
@@ -74,8 +74,14 @@ class VIEWS_EXPORT TooltipController : public aura::client::TooltipClient,
int GetTooltipShownTimeout();
+ // Sets tooltip window to |target| if it is different from existing window.
+ // Calls RemoveObserver on the existing window if it is not NULL.
+ // Calls AddObserver on the new window if it is not NULL.
+ void SetTooltipWindow(aura::Window* target);
+
aura::Window* tooltip_window_;
base::string16 tooltip_text_;
+ const void* tooltip_id_;
// These fields are for tracking state when the user presses a mouse button.
aura::Window* tooltip_window_at_mouse_press_;
@@ -61,7 +61,7 @@ class VIEWS_EXPORT TooltipController : public aura::client::TooltipClient,
void TooltipShownTimerFired();
// Updates the tooltip if required (if there is any change in the tooltip
- // text or the aura::Window.
+ // text, tooltip id or the aura::Window).
void UpdateIfRequired();
// Only used in tests.